@@ -20,7 +20,7 @@
 # IN THE SOFTWARE.
 
 __author__ = 'Niklas Rosenstein <rosensteinniklas@gmail.com>'
-__version__ = '0.0.1'
+__version__ = '0.0.2'
 __all__ = ['parse_python', 'Parser']
 
 from .parser import Parser
@@ -42,7 +42,7 @@ def parse_python(
 
   if isinstance(f, str):
     with open(f) as fp:
-      return parse_python(fp)
+      return parse_python(fp, filename, module_name, **options)
 
   filename = filename or getattr(f, 'name', None)
   parser = Parser(**options)
