@@ -120,7 +120,7 @@ class Parser:
       decorations = []
       if node.children[0].type == syms.decorator:
         decorator_nodes = [node.children[0]]
-      elif node.children[0].type == syms.decorations:
+      elif node.children[0].type == syms.decorators:
         decorator_nodes = node.children[0].children
       else:
         assert False, node.children[0].type
@@ -232,7 +232,7 @@ class Parser:
       default = self.nodes_to_string([node])
       node = scanner.advance()
 
-    return Argument(name, argtype, annotation, default)
+    return Argument(name, argtype, None, annotation, default)
 
   def parse_parameters(self, parameters):
     assert parameters.type == syms.parameters, parameters.type
@@ -247,9 +247,10 @@ class Parser:
         scanner = ListScanner(parameters.children, parameters.children.index(tname))
         result.append(self.parse_argument(tname, Argument.Type.Positional, scanner))
       else:
+        # This must be either ["(", ")"] or ["(", "argname", ")"].
         assert len(parameters.children) in (2, 3), parameters.children
         if len(parameters.children) == 3:
-          result.append(Argument(parameters.children[1].value, Argument.Type.Positional, None, None))
+          result.append(Argument(parameters.children[1].value, Argument.Type.Positional, None, None, None))
       return result
 
     argtype = Argument.Type.Positional
@@ -259,12 +260,9 @@ class Parser:
       node = index.current
       if node.type == token.STAR:
         node = index.advance()
-        if node.type == token.COMMA:
-          #result.append(Argument('', None, None, Argument.KW_SEPARATOR))
-          index.advance()
-        else:
+        if node.type != token.COMMA:
           result.append(self.parse_argument(node, Argument.Type.PositionalRemainder, index))
-          index.advance()
+        index.advance()
         argtype = Argument.Type.KeywordOnly
         continue
       elif node.type == token.DOUBLESTAR:
